@@ -63,6 +63,9 @@ pub(crate) enum Error<'src> {
   Dotenv {
     dotenv_error: dotenv::Error,
   },
+  DumpJson {
+    serde_json_error: serde_json::Error,
+  },
   EditorInvoke {
     editor: OsString,
     io_error: io::Error,
@@ -75,6 +78,7 @@ pub(crate) enum Error<'src> {
     variable: String,
     suggestion: Option<Suggestion<'src>>,
   },
+  FormatCheckFoundDiff,
   FunctionCall {
     function: Name<'src>,
     message: String,
@@ -433,6 +437,9 @@ impl<'src> ColorDisplay for Error<'src> {
       Dotenv { dotenv_error } => {
         write!(f, "Failed to load environment file: {}", dotenv_error)?;
       }
+      DumpJson { serde_json_error } => {
+        write!(f, "Failed to dump JSON to stdout: {}", serde_json_error)?;
+      }
       EditorInvoke { editor, io_error } => {
         write!(
           f,
@@ -458,6 +465,9 @@ impl<'src> ColorDisplay for Error<'src> {
           write!(f, "\n{}", suggestion)?;
         }
       }
+      FormatCheckFoundDiff => {
+        write!(f, "Formatted justfile differs from original.")?;
+      }
       FunctionCall { function, message } => {
         write!(
           f,
