@@ -284,6 +284,15 @@ impl<'src> Justfile<'src> {
     search: &Search,
     ran: &mut BTreeSet<Vec<String>>,
   ) -> RunResult<'src, ()> {
+    let mut invocation = vec![recipe.name().to_owned()];
+    for argument in arguments {
+      invocation.push((*argument).to_string());
+    }
+
+    if ran.contains(&invocation) {
+      return Ok(());
+    }
+
     let (outer, positional) = Evaluator::evaluate_parameters(
       context.config,
       dotenv,
@@ -300,20 +309,19 @@ impl<'src> Justfile<'src> {
       Evaluator::recipe_evaluator(context.config, dotenv, &scope, context.settings, search);
 
     for Dependency { recipe, arguments } in recipe.dependencies.iter().take(recipe.priors) {
-      let mut invocation = vec![recipe.name().to_owned()];
+      let arguments = arguments
+        .iter()
+        .map(|argument| evaluator.evaluate_expression(argument))
+        .collect::<RunResult<Vec<String>>>()?;
 
-      for argument in arguments {
-        invocation.push(evaluator.evaluate_expression(argument)?);
-      }
-
-      if !ran.contains(&invocation) {
-        let arguments = invocation
-          .iter()
-          .skip(1)
-          .map(String::as_ref)
-          .collect::<Vec<&str>>();
-        self.run_recipe(context, recipe, &arguments, dotenv, search, ran)?;
-      }
+      self.run_recipe(
+        context,
+        recipe,
+        &arguments.iter().map(String::as_ref).collect::<Vec<&str>>(),
+        dotenv,
+        search,
+        ran,
+      )?;
     }
 
     recipe.run(context, dotenv, scope.child(), search, &positional)?;
@@ -339,11 +347,6 @@ impl<'src> Justfile<'src> {
       }
     }
 
-    let mut invocation = vec![recipe.name().to_owned()];
-    for argument in arguments {
-      invocation.push((*argument).to_string());
-    }
-
     ran.insert(invocation);
     Ok(())
   }
