@@ -1,7 +1,4 @@
-use std::{fs, path::Path, process, str};
-
-use executable_path::executable_path;
-use test_utilities::tempdir;
+use crate::common::*;
 
 #[cfg(unix)]
 fn convert_native_path(path: &Path) -> String {
@@ -15,7 +12,7 @@ fn convert_native_path(path: &Path) -> String {
 #[cfg(windows)]
 fn convert_native_path(path: &Path) -> String {
   // Translate path from windows style to unix style
-  let mut cygpath = process::Command::new("cygpath");
+  let mut cygpath = Command::new("cygpath");
   cygpath.arg("--unix");
   cygpath.arg(path);
 
@@ -51,7 +48,7 @@ fn test_invocation_directory() {
   subdir.push("subdir");
   fs::create_dir(&subdir).unwrap();
 
-  let output = process::Command::new(&executable_path("just"))
+  let output = Command::new(&executable_path("just"))
     .current_dir(&subdir)
     .args(&["--shell", "sh"])
     .output()
